@@ -18,7 +18,7 @@ class TestSampling(unittest.TestCase):
     def is_sampler(self, sampler):
         """Test if a sampler is a sampler."""
         self.assertIsInstance(sampler, types.GeneratorType)
-        for x in range(10):
+        for _ in range(10):
             sample = next(sampler)
             self.assertIsInstance(sample, np.ndarray)
             self.assertEqual(
@@ -43,6 +43,7 @@ class TestSampling(unittest.TestCase):
         """Test halton sampling."""
         sampler = sampling.halton_sampling(self._dim)
         self.is_sampler(sampler)
+        self.assertEqual(sampling.Halton.vectorized_next(10, 2), .3125)
 
     def test_orthogonal(self):
         """Test orthogonal sampling."""
